@@ -12,8 +12,11 @@ from bleak.exc import BleakDBusError, BleakError
 from aiohomekit.characteristic_cache import CharacteristicCacheType
 from aiohomekit.controller.abstract import AbstractController, AbstractPairingData
 from aiohomekit.controller.ble.manufacturer_data import (
+    APPLE_MANUFACTURER_ID,
+    HOMEKIT_ADVERTISEMENT_TYPE,
+    HOMEKIT_ENCRYPTED_NOTIFICATION_TYPE,
     HomeKitAdvertisement,
-    is_homekit_advertisement,
+    HomeKitEncryptedNotification,
 )
 from aiohomekit.controller.ble.pairing import BlePairing
 
@@ -42,31 +45,48 @@ class BleController(AbstractController):
     def _device_detected(
         self, device: BLEDevice, advertisement_data: AdvertisementData
     ) -> None:
-        # Since we are getting everything, reject anything that is not a HomeKit device
-        # as early as possible to avoid the try/except overhead.
-        if not is_homekit_advertisement(advertisement_data):
+        manufacturer_data = advertisement_data.manufacturer_data
+        if not (mfr_data := manufacturer_data.get(APPLE_MANUFACTURER_ID)):
+            return
+
+        elif mfr_data[0] == HOMEKIT_ENCRYPTED_NOTIFICATION_TYPE:
+            try:
+                data = HomeKitEncryptedNotification.from_manufacturer_data(
+                    device.name, device.address, manufacturer_data
+                )
+            except ValueError:
+                return
+
+            logger.debug("Got encrypted notification: %s", data)
+
+            if pairing := self.pairings.get(data.id):
+                pairing._async_notification(data)
+
+            return
+
+        if mfr_data[0] != HOMEKIT_ADVERTISEMENT_TYPE:
             return
 
         try:
             data = HomeKitAdvertisement.from_manufacturer_data(
-                device.name, device.address, advertisement_data.manufacturer_data
+                device.name, device.address, manufacturer_data
             )
         except ValueError:
             return
 
         if pairing := self.pairings.get(data.id):
             pairing._async_description_update(data)
-            pairing._async_ble_device_update(device)
+            pairing._async_ble_update(device, advertisement_data)
 
         if futures := self._ble_futures_by_id.get(data.id):
-            discovery = BleDiscovery(self, device, data)
+            discovery = BleDiscovery(self, device, data, advertisement_data)
             logger.debug("BLE device for %s found, fulfilling futures", data.id)
             for future in futures:
                 future.set_result(discovery)
             futures.clear()
 
         if futures := self._ble_futures.get(data.address):
-            discovery = BleDiscovery(self, device, data)
+            discovery = BleDiscovery(self, device, data, advertisement_data)
             logger.debug("BLE device for %s found, fulfilling futures", data.address)
             for future in futures:
                 future.set_result(discovery)
@@ -75,10 +95,12 @@ class BleController(AbstractController):
         if data.id in self.discoveries:
             # We need to make sure we update the device details
             # in case they changed
-            self.discoveries[data.id]._async_process_advertisement(device, data)
+            self.discoveries[data.id]._async_process_advertisement(
+                device, data, advertisement_data
+            )
             return
 
-        self.discoveries[data.id] = BleDiscovery(self, device, data)
+        self.discoveries[data.id] = BleDiscovery(self, device, data, advertisement_data)
 
     async def async_start(self) -> None:
         logger.debug("Starting BLE controller with instance: %s", self._scanner)
